This folder is only for use with `wq start --without-npm`.  Projects using `wq start --with-npm` will use [@wq/cra-template] instead.

[@wq/cra-template]: https://github.com/wq/wq.start/tree/master/packages/cra-template
